.get_reserved_operator: Check for reserved operators
Description
A helper for .make_parameters(), which takes a symbol and checks
whether it corresponds to one of the reserved operators for the package
syntax.
Usage
.get_reserved_operator(node)
Value
If node is a reserved operator, then return the operator as a
string. Otherwise return the string "none".
Arguments
- node
A symbol, extracted from a formula