Utility to print all contrast matrices for a given dataframe.
Displays fractional values with MASS::fractions().
Prints nothing if there are no factor columns in the dataframe.
Usage
print_contrasts(x, specific_vars)
Value
Nothing
Arguments
x
Dataframe containing factor columns
specific_vars
Character vector of specific factor columns to print
contrasts for. Use to only print a certain subset of variables.